@@ -26,41 +26,49 @@ def get_table_dtypes(schema_name: str, table_name: str):
 def get_num_null(table_name: str):
     client = bigquery.Client()
     res = client.query(f"""
-    SELECT col_name, COUNT(1) nulls_count
-    FROM `{project_ID}.{schema_name}.{table_name}` t, UNNEST(REGEXP_EXTRACT_ALL(TO_JSON_STRING(t), r'"(\w+)":null')) col_name
-    GROUP BY col_name
-    """)
+        SELECT col_name, COUNT(1) nulls_count
+        FROM `{project_ID}.{schema_name}.{table_name}` t, UNNEST(REGEXP_EXTRACT_ALL(TO_JSON_STRING(t), r'"(\w+)":null')) col_name
+        GROUP BY col_name
+        """)
     return {row[0]: row[1] for row in res.result()}
 
 
 def metrics_numeric(table_name: str, col_name: str, dtype: str):
     client = bigquery.Client()
     res = client.query(f"""
-    SELECT min({col_name}) min, max({col_name}) max
-    FROM `{project_ID}.{schema_name}.{table_name}`    
-    """)
+        SELECT COUNT(DISTINCT {col_name}) unique, 
+        MIN({col_name}) min, 
+        MAX({col_name}) max, 
+        COUNTIF({col_name} IS NULL) null_count
+        FROM `{project_ID}.{schema_name}.{table_name}`
+        """)
     for row in res.result():
-        return {"dtype": dtype, "min": row[0], "max": row[1]}
+        return {"dtype": dtype, "unique": row[0],"min": row[1], "max": row[2], "num_null": row[3]}
 
 
 def metrics_string(table_name: str, col_name: str, dtype: str):
     client = bigquery.Client()
     res = client.query(f"""
-    SELECT COUNT(DISTINCT {col_name})
-    FROM `{project_ID}.{schema_name}.{table_name}`    
-    """)
+        SELECT COUNT(DISTINCT {col_name}), 
+        COUNTIF({col_name} IS NULL) null_count
+        FROM `{project_ID}.{schema_name}.{table_name}`    
+        """)
     for row in res.result():
-        return {"dtype": dtype, "unique": row[0]}
+        return {"dtype": dtype, "unique": row[0], "num_null": row[3]}
 
 
 def metrics_date(table_name: str, col_name: str, dtype: str):
     client = bigquery.Client()
     res = client.query(f"""
-    SELECT COUNT(DISTINCT {col_name}), MIN({col_name}), MAX({col_name})
-    FROM `{project_ID}.{schema_name}.{table_name}`    
-    """)
+        SELECT COUNT(DISTINCT {col_name}), 
+        MIN({col_name}), 
+        MAX({col_name}), 
+        COUNTIF({col_name} IS NULL) null_count
+        FROM `{project_ID}.{schema_name}.{table_name}`    
+        """)
     for row in res.result():
-        return {"dtype": dtype, "unique:": row[0], "min": row[1], "max": row[2]}
+        return {"dtype": dtype, "unique:": row[0], "min": row[1], "max": row[2], "num_null": row[3]}
+
 
 def column_metrics(table_name: str):
     out = {}
